/**
 * Copyright 2007-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.archive.impl;

import java.util.Map;
import java.util.Set;
import java.util.jar.Attributes;
import java.util.jar.Manifest;

import org.ow2.util.archive.api.IArchive;
import org.ow2.util.archive.api.IArchiveMetadata;

/**
 * Common code for analyzing manifest.
 * @author Florent BENOIT
 */
public abstract class AbsArchiveImpl implements IArchive {

    /**
     * Logger.
     */
    //private Log logger = LogFactory.getLog(AbsArchiveImpl.class);

    /**
     * Link to a metadata implementation.
     */
    private IArchiveMetadata archiveMetadata = null;

    /**
     * Default constructor.
     */
    public AbsArchiveImpl() {
        this.archiveMetadata = new ArchiveMetadataImpl();
    }

    /**
     * Read the manifest and complete the metadata.
     * @param manifest the given manifest to analyze
     */
    protected void readManifest(final Manifest manifest) {
        // Now manifest is here, analyze it and populate metadata
        Attributes attributes = manifest.getMainAttributes();
        Set<Map.Entry<Object, Object>> entries = attributes.entrySet();
        for (Map.Entry<Object, Object> entry : entries) {
            archiveMetadata.put(entry.getKey().toString(), entry.getValue().toString());
        }
    }

    /**
     * @return the Metadata associated to this archive.
     */
    public IArchiveMetadata getMetadata() {
        return archiveMetadata;
    }

    /**
     * @return a string representation of the object.
     */
    @Override
    public String toString() {
        return getName();
    }

}
